.. _utils.math_helpers:

Mathematical Helpers
====================

.. automodule:: eyetrace.utils.math_helpers
   :members:
   :undoc-members:
   :show-inheritance:

General mathematical utilities: outlier removal based on median absolute
deviation, sliding window view of arrays, and simple peak detection.